/*
 * Sonar, entreprise quality control tool.
 * Copyright (C) 2007-2008 Hortis-GRC SA
 * mailto:be_agile HAT hortis DOT ch
 *
 * Sonar is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 3 of the License, or (at your option) any later version.
 *
 * Sonar is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with {library}; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02
 */
package ch.hortis.sonar.model;

import java.io.Serializable;
import java.util.ArrayList;
import java.util.List;

import javax.persistence.*;

import org.apache.commons.lang.builder.EqualsBuilder;
import org.apache.commons.lang.builder.HashCodeBuilder;
import org.apache.commons.lang.builder.ToStringBuilder;
import org.hibernate.annotations.ForeignKey;

@Entity
@Table(name = "file_measures")
public class FileMeasure extends MetricMeasure implements Serializable, WithFile, Collectable {
  
  private static final long serialVersionUID = -8547266020380372485L;

  @Id
  @Column(name = "id")
  @SequenceGenerator(name= "FILE_MEASURES_SEQ", sequenceName = "FILE_MEASURES_SEQ")
  @GeneratedValue(strategy = GenerationType.AUTO, generator = "FILE_MEASURES_SEQ")
  private Integer id;

  @ManyToOne(optional=true,fetch = FetchType.LAZY, cascade = {CascadeType.MERGE, CascadeType.PERSIST, CascadeType.REFRESH})
  @JoinColumn(name = "file_id", updatable = false, nullable = false)
  private File file;

  public FileMeasure() {
  }
  
  public FileMeasure( Snapshot snapshot, Metric metric, Double value, File file ) {
    super.snapshot = snapshot;
    super.metric = metric;
    super.value = value;
    this.file = file;
  }
  
  public Integer getId() {
    return id;
  }

  public void setId( Integer id ) {
    this.id = id;
  }

  public File getFile() {
    return file;
  }

  public void setFile(File file) {
    this.file = file;
  }

  public boolean equals(Object obj) {
    if (!(obj instanceof FileMeasure)) {
      return false;
    }
    if (this == obj) {
      return true;
    }
    FileMeasure other = (FileMeasure) obj;
    return new EqualsBuilder()
        .append(id, other.getId()).isEquals();
  }

  public int hashCode() {
    return new HashCodeBuilder().append(id).toHashCode();
  }

  public String toString() {
    return new ToStringBuilder(this).
       append("id", id).
       append("value", value).
       append("metric", metric).
       append("file", file).
       toString();
  }
}